@@ -61,7 +61,8 @@ M4A = function(data, BadStart, nchains, method, niter, lambda.min){
             return(R)
         }
         else {
-            R = dmixedvonmises(data, mu1 = circular(params[1]), mu2 = circular(params[1]+pi, modulo = "2pi"), kappa1 = params[2], kappa2 = params[2], prop = params[3])
+        	P = circularp(data)
+            R = dmixedvonmises(data, mu1 = as.circular(params[1], control.circular = P), mu2 = as.circular(params[1]+pi, control.circular = P), kappa1 = params[2], kappa2 = params[2], prop = params[3])
             R = -sum(log(R))
             return(R)
         }
